┌   ┐
54
└   ┘

summaryrefslogtreecommitdiff
path: root/src/kitemviews/kfileitemmodel.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/kitemviews/kfileitemmodel.h')
-rw-r--r--src/kitemviews/kfileitemmodel.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/kitemviews/kfileitemmodel.h b/src/kitemviews/kfileitemmodel.h
index 5d75329d1..160817043 100644
--- a/src/kitemviews/kfileitemmodel.h
+++ b/src/kitemviews/kfileitemmodel.h
@@ -97,9 +97,9 @@ public:
int index(const KFileItem& item) const;
/**
* @return Root directory of all items.
*/
- KUrl rootDirectory() const;
+ KFileItem rootItem() const;
/**
* Clears all items of the model.
@@ -97,9 +97,9 @@ public:
int index(const KFileItem& item) const;
/**
- * @return Root directory of all items.
+ * @return Root item of all items.
*/